@@ -26,7 +26,7 @@ function change_passwd_plugin_optpage_register_block()
 
 function change_passwd_version() 
 {
-   return '3.0.1';
+   return '3.1';
 }
 
 ?>
